@@ -15,17 +15,8 @@ A construct to create a private asset S3 bucket. Cognito will be used for token
 # Example
 
 ```python
-import { ProwlerAudit } from 'cdk-prowler';
-...
-    const app = new core.App();
-
-    const stack = new core.Stack(app, 'PrivateAssetBucket-stack2', {
-      env: {
-        account: '981237193288',
-        region: 'us-east-1',
-      },
-    });
-
+    import { PrivateAssetBucket } from 'cdk-private-assets-bucket';
+    ...
     const userPool = new cognito.UserPool(stack, 'userPool', {
       removalPolicy: core.RemovalPolicy.DESTROY,
     });
@@ -100,17 +91,25 @@ echo "curl --location --request GET "https://$CFD/pic.png" --cookie "Cookie: tok
 
 * You can use the curl for importing in Postman. but it looks like Postman can't import the cookie. So you need to set the cookie manually in Postman!
 * In Postman you should see your picture :)
+* For Debugging the Lambda@Edge with Cloudwatch go to the AWS Console --> Cloudwatch --> Log groups --> switch to the region you are closest to --> figure out which log group is correct
 
 ## Planned Features
 
+* Migrating to cdk v2. If you know a cool workflow how to continuously support v1 and v2 let me know!
 * Support S3 bucket import ootb.
 * Support custom authorizer
+* Leverage Cloudfront Function for cheaper costs
+
+## Misc
+
+* There is currently my aws-cdk PR open for importing the Typescript Lambda@Edge interface https://github.com/aws/aws-cdk/pull/18836
 
 ## Thanks To
 
 * Crespo Wang for his pioneer work regarding private S3 assets https://javascript.plainenglish.io/use-lambda-edge-jwt-to-secure-s3-bucket-dcca6eec4d7e
 * As always to the amazing CDK / Projen Community. Join us on [Slack](https://cdk-dev.slack.com)!
 * [Projen](https://github.com/projen/projen) project and the community around it
+* To you for checking this out. Check me out and perhaps give me feedback https://martinmueller.dev
 '''
 import abc
 import builtins
